==> sitemodels-0.3.28.tgz: package/lib/getsassdoc.js <==
//
//  getSassdoc.js
//
//  Return data structure containing all html from the sassdoc output 
//  for every variable, placeholder, mixin, and function documented.
//

var _ = require('./help.js'),
    fs = require('fs');

var prism = require('../node_modules/prismjs/components/prism-core.js');
    require('../node_modules/prismjs/components/prism-scss.js');

module.exports = (function() {

  var itemCodeExp = /(<pre[^>]+?data-expanded="([^"]+?)"[^]+?<\/pre>)/g;
  var itemCodeNoCollapse = /(<pre\sclass="item__code.+?".+<code>([^]+?)<\/code><\/pre>)/g;
  var exampleCodeExp = /(<pre\sclass="example[^]+?<code>([^]+?)<\/code><\/pre>)/g;

  function getItems(content, thing) {
    var itemExp = new RegExp('(<section\\sclass="main__item\\scontainer\\sitem"\\sid="\\w+?-'+thing+'-([\\w\\-]+?)"[^]+?<\\/section>)', 'g');
    return _.find(content, itemExp, true, 2);
  }

  function makeObj(list) {
    var output = {};
    list.forEach(function(found) {
      output[found[2]] = found[1];
    })
    return output;
  }

  function getItemCode(content) {
    var output = _.find(content, itemCodeExp, true, 2),
        nonCollapsed = _.find(content, itemCodeNoCollapse, true, 2),
        converted = '';

    if (output.length) {

      converted += '<code class="sm-sassdoc-item-code"><pre class="language-sass">';
      converted += prism.highlight(output[0]['2'].replace(/\&quot;/g, '"').replace(/\&#39;/g, "'"), prism.languages.scss);
      converted += '</pre></code>';

      return content.replace(output[0]['1'], converted);

    } else if (nonCollapsed.length) {

      converted += '<code class="sm-sassdoc-item-code"><pre class="language-sass">';
      converted += prism.highlight(nonCollapsed[0]['2'].replace(/\&quot;/g, '"').replace(/\&#39;/g, "'"), prism.languages.scss);
      converted += '</pre></code>';

      return content.replace(nonCollapsed[0]['1'], converted);

    } else {
      return content;
    }
  }

  function getExampleCode(content) {
    var output = _.find(content, exampleCodeExp, true, 2),
        converted = '';
  
    if (output.length) {
      converted += '<code class="sm-sassdoc-example-code"><pre class="language-sass">';
      converted += prism.highlight(output[0]['2'].replace(/\&quot;/g, '"').replace(/\&#39;/g, "'"), prism.languages.scss);
      converted += '</pre></code>';

      return content.replace(output[0]['1'], converted);

    } else {
      return content;
    }
  }

  function convertCode(items) {
    var output = _.copy(items);
    for (var item in output) {
      output[item] = getItemCode(getExampleCode(output[item]));
    }
    return output;
  }

  return function(path) {

    var output = {};
    var docs = _.contents(_.endSlash(path) + 'index.html');

    output.variables = convertCode(makeObj(getItems(docs, 'variable')));
    output.placeholders = convertCode(makeObj(getItems(docs, 'placeholder')));
    output.functions = convertCode(makeObj(getItems(docs, 'function')));
    output.mixins = convertCode(makeObj(getItems(docs, 'mixin')));

    return JSON.stringify(output);

  }


})();

==> sitemodels-0.3.31.tgz: package/lib/getsassdoc.js <==
//
//  getSassdoc.js
//
//  Return data structure containing all html from the sassdoc output 
//  for every variable, placeholder, mixin, and function documented.
//

var _ = require('./help.js'),
    fs = require('fs');

var prism = require('../node_modules/prismjs/components/prism-core.js');
    require('../node_modules/prismjs/components/prism-scss.js');

module.exports = (function() {

  var itemCodeExp = /(<pre[^>]+?data-expanded="([^"]+?)"[^]+?<\/pre>)/g;
  var itemCodeNoCollapse = /(<pre\sclass="item__code.+?".+<code>([^]+?)<\/code><\/pre>)/g;
  var exampleCodeExp = /(<pre\sclass="example[^]+?<code>([^]+?)<\/code><\/pre>)/g;

  function decode(text) {
    return text
      .replace(/\&quot;/g, '"')
      .replace(/\&#39;/g, "'")
      .replace(/\&lt;/g,'<')
      .replace(/\&gt;/g, '>');
  }

  function getItems(content, thing) {
    var itemExp = new RegExp('(<section\\sclass="main__item\\scontainer\\sitem"\\sid="\\w+?-'+thing+'-([\\w\\-]+?)"[^]+?<\\/section>)', 'g');
    return _.find(content, itemExp, true, 2);
  }

  function makeObj(list) {
    var output = {};
    list.forEach(function(found) {
      output[found[2]] = found[1];
    })
    return output;
  }

  function getItemCode(content) {
    var output = _.find(content, itemCodeExp, true, 2),
        nonCollapsed = _.find(content, itemCodeNoCollapse, true, 2),
        converted = '';

    if (output.length) {

      converted += '<code class="sm-sassdoc-item-code"><pre class="language-sass">';
      converted += prism.highlight(decode(output[0]['2']), prism.languages.scss);
      converted += '</pre></code>';

      return content.replace(output[0]['1'], converted);

    } else if (nonCollapsed.length) {

      converted += '<code class="sm-sassdoc-item-code"><pre class="language-sass">';
      converted += prism.highlight(decode(nonCollapsed[0]['2']), prism.languages.scss);
      converted += '</pre></code>';

      return content.replace(nonCollapsed[0]['1'], converted);

    } else {
      return content;
    }
  }

  function getExampleCode(content) {
    var output = _.find(content, exampleCodeExp, true, 2),
        converted = '';
  
    if (output.length) {
      converted += '<code class="sm-sassdoc-example-code"><pre class="language-sass">';
      converted += prism.highlight(decode(output[0]['2']), prism.languages.scss);
      converted += '</pre></code>';

      return content.replace(output[0]['1'], converted);

    } else {
      return content;
    }
  }

  function convertCode(items) {
    var output = _.copy(items);
    for (var item in output) {
      output[item] = getItemCode(getExampleCode(output[item]));
    }
    return output;
  }

  return function(path) {

    var output = {};
    var docs = _.contents(_.endSlash(path) + 'index.html');

    output.variables = convertCode(makeObj(getItems(docs, 'variable')));
    output.placeholders = convertCode(makeObj(getItems(docs, 'placeholder')));
    output.functions = convertCode(makeObj(getItems(docs, 'function')));
    output.mixins = convertCode(makeObj(getItems(docs, 'mixin')));

    return JSON.stringify(output);

  }


})();
